#include <windows.h>
#include "resource.h"

LRESULT CALLBACK WndProc( HWND, UINT, WPARAM, LPARAM );

char szAppName[]= "MFonts";	// Application, and Window class name

int WINAPI WinMain( HINSTANCE hInst, HINSTANCE hPrevInst, LPSTR lpszArgs, int nCmdShow )
{
	HWND hWnd;
	MSG Msg;
	WNDCLASS WndClass;

	WndClass.hInstance = hInst;
	WndClass.lpszClassName = szAppName;
	WndClass.lpfnWndProc = WndProc;
	WndClass.style = 0;	// No special styles

	WndClass.hIcon = LoadIcon( NULL, IDI_APPLICATION );
	WndClass.hCursor = LoadCursor( NULL, IDC_ARROW );
	WndClass.lpszMenuName = MAKEINTRESOURCE(IDR_MENU1);
	WndClass.hbrBackground = CreateSolidBrush( GetSysColor(COLOR_WINDOW));


	WndClass.cbClsExtra = 0; // 'Extra' information about this window,
	WndClass.cbWndExtra = 0; // our program has none.

	if( !RegisterClass( &WndClass ) )
	{
		MessageBox( NULL, "Error registering class", NULL, MB_ICONEXCLAMATION|MB_OK );
		return( 0 );
	}

	hWnd = CreateWindow( szAppName, "Font List", WS_OVERLAPPEDWINDOW,
		CW_USEDEFAULT, CW_USEDEFAULT, CW_USEDEFAULT, CW_USEDEFAULT, 
		HWND_DESKTOP, NULL, hInst, NULL );

	
	ShowWindow( hWnd, nCmdShow );
	UpdateWindow( hWnd );

	while( GetMessage( &Msg, NULL, 0, 0 ) )
	{
		TranslateMessage( &Msg );
		SendMessage( Msg.hwnd, Msg.message, Msg.wParam, Msg.lParam );
	}

	return( Msg.wParam );
}

/* This function is used by EnumFonts.  This function uses the FontCount
** global variable, to determine when to stop 'iterating'
*/
int FontCount;
int CALLBACK MyFontEnum(  LOGFONT * lplf,  TEXTMETRIC* lptm,  DWORD dwType,  LPARAM lpData  )
{
	if( FontCount-- == 0 )
	{
		strcpy( (char*)lpData, lplf->lfFaceName );
		return( 0 );
	}
	(*(char*) lpData)='\0';
	return(1);
}


LRESULT CALLBACK WndProc( HWND hWnd, UINT Message, WPARAM wParam, LPARAM lParam )
{
	// This is the 'message handler', handling all messages sent to our window
	switch( Message )
	{
			// WM_COMMAND indicates menu selection of button click.	
		case WM_COMMAND:
			switch( LOWORD( wParam ) )
			{
				case ID_MENUEXIT:
					SendMessage( hWnd, WM_CLOSE, 0, 0 );
				break;
			}
			return( DefWindowProc( hWnd, Message, wParam, lParam ) );
		case WM_PAINT:
			{	/* This paint code will list all fonts to the window */
				HDC DC;
				PAINTSTRUCT PaintStruct;
				DC = BeginPaint( hWnd, &PaintStruct );
				char Font[64];
				HFONT OldFont=0, NewFont;
				int i=0;
				do {
					FontCount = i++;
					Font[0]='\0';
					EnumFonts( DC, NULL, (FONTENUMPROC)MyFontEnum, (DWORD)Font );
					if( Font[0] != '\0' )
					{
						NewFont = CreateFont( -15, 0, 0, 0, FW_NORMAL,
							FALSE, FALSE, FALSE, DEFAULT_CHARSET, OUT_DEFAULT_PRECIS,
							CLIP_DEFAULT_PRECIS, DEFAULT_QUALITY, 
							DEFAULT_PITCH|FF_DONTCARE, Font );
						if( NewFont==0 )
						{
							SelectObject( DC, OldFont );
							MessageBox( hWnd, "Error creating font", NULL, MB_OK );
							break;
						}
						OldFont = SelectObject( DC, NewFont );
						SelectObject( DC, NewFont );
						TextOut( DC, 0, i*17, Font, strlen(Font) );
						SelectObject( DC, OldFont );
						DeleteObject( NewFont );
					}
					
				} while( Font[0] != '\0' );
				EndPaint( hWnd, &PaintStruct );
			}
			break;
		case WM_CLOSE:
			if( MessageBox( NULL, "Are you sure?", "Confirmation", MB_ICONQUESTION|MB_YESNO) == IDYES )
				DestroyWindow( hWnd );
			break;
		case WM_DESTROY:
			PostQuitMessage(0);
			break;
		default:
			// Any unhandled messages are passed onto to the default handler.
			return( DefWindowProc( hWnd, Message, wParam, lParam ) );
	}
	return( DefWindowProc( hWnd, Message, wParam, lParam ) );
}
